[![PyPI version](https://badge.fury.io/py/omegaconf.svg)](https://badge.fury.io/py/omegaconf)
[![Build Status](https://travis-ci.com/omry/omegaconf.svg?branch=master)](https://travis-ci.com/omry/omegaconf)
[![Documentation Status](https://readthedocs.org/projects/omegaconf/badge/?version=latest)](https://omegaconf.readthedocs.io/en/latest/?badge=latest)

# OmegaConf

OmegaConf is a YAML based hierarchical configuration system, with support for merging configurations from multiple sources (multiple config files, CLI argument)
providing a consistent API regardless of how the configuration was created.

[Read the docs](https://omegaconf.readthedocs.io/en/latest/?badge=latest).
